[![version badge]](https://pypi.org/project/hive-config/)

[version badge]: https://img.shields.io/pypi/v/hive-config?color=limegreen

# hive-config

Configuration management for Hive.

## Installation

### With PIP

```sh
pip install hive-config
```
